#include "heinlib_autocalibrate.h"

int main()
{
	using namespace heinlib;
	typedef double Real;
	typedef static_matrix<2,1,Real> Feature;
	
	//load existing image point observations and projective reconstruction
	feature_observations<Feature> observations;
	observations.load_ascii("observations.txt");
	projective_recon<Real> proj_recon;
	proj_recon.load<1>("proj_recon.txt");

	//setup parameters
	unsigned image_width = 640, image_height = 480;
	Real min_f = image_width*0.6, max_f = image_width*3;
	Real u = image_width*0.5, v = image_height*0.5;
	Real max_sq_err_thresh = sq(5);
	static_matrix<4,4,Real> H;

	//perform autocalibration to find rectifying homography (H)
	MC_ML_autocalibrate<2>( H, proj_recon, observations, min_f, max_f, u, v, max_sq_err_thresh );

	//load projective reconstruction into a metric structure
	metric_recon<Real> recon( proj_recon, H, image_width, image_height );

	//print out calibration matrices
	for(int i=0; i<recon.camera_views.size(); ++i)
		std::cout << "K" << i << " = \n" << recon.camera_views[i].intrinsics->K << "\n\n";

	//export to PLY file (can view with meshlab)
	export_ply( "metric_recon.ply", recon );

}